      SUBROUTINE AISTCG
*.
*...AISTCG   backward scattering Compton Gamma energy dist. generator
*.
*. SEQUENCE  : AIST LPFLAG
*. CALLS     : HBOOK1 XSRNDM HF1 HRPUT UHTOC HREND
*. CALLED    : UGINIT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : W.Ootani
*. VERSION   : 1.01
*. CREATED   : 31-Mar-02
*. LAST MOD  : 06-Jul-02
*.
*. Modification Log.
*. 06-Jul-02   K.Ozone        (V1.01) Momentum distribustion named BSC*
*.                            was unified to *DST* and MHNAM in LPFLAG.
*. 31-Mar-02   K.Ozone        (V1.00) Translated into Fortran for incorporating
*.                            to GEANT3.
*. 21-Mar-02   W.Ootani       (NoVer) Creation in C++.
*.
*.**********************************************************************
*.

#include "declare.inc"
#include "aistcg.inc"
#include "lpflag.inc"

*
*-- constants in mathematics and pysics
*
	REAL*8 PI                 ! pi
	REAL*8 ELCR               ! classical radius of electron in meter
	REAL*8 ELCM               ! electron mass in MeV
	PARAMETER (PI=3.141592653589793D0)
	PARAMETER (ELCR=2.81794D-15, ELCM=0.5109989D0)
*
*-- electron beam properties
*
	REAL*8 ELCE               ! incidental electron beam energy
	REAL*8 ELCDE              ! ???
	REAL*8 ELCBT              ! beta of elctron
	REAL*8 ELCGM              ! Lorentz factor of electron
*
*--   LASER photon properties
*
	REAL*8 PHTE               ! energy of scatterd gamma at lab. frame
	REAL*8 PHTES              !
*
*--   Collimator geometry
*
	REAL*8 COLA               ! collimator opening angle(half angle) in rad
*
*--   Collision
*
	REAL*8 COLX               ! Collision point
	REAL*8 THCEFF             !
	REAL*8 THETA0,THETA4,THETA1,THETA3,THETA5,THETA6
*
*--   variables for loop and random number
*
	INTEGER I
	INTEGER NEVE
	PARAMETER (NEVE=100000)
	REAL RN(2)
*
*--   temporary variables on calculating
*
	REAL*8 X1, X2, X3, X4, TEMP
	REAL FPHTE, FPHTES
*
*--   configuration
*
	ELCDE = ELCE0*ELCE0/2.355D0*6.25D-6
	ELCGM = ELCE0/ELCM
	ELCBT = SQRT(1D0-1D0/ELCGM/ELCGM)
	COLA  = COLR/COLD
*      write(*,*) ELCE0, ELCAD, ELCD, PHTE1, COLD, COLR
*
*--   create histogram
*
	CALL HBOOK1(DSTHID(6), 'compton', 450, 0, 45, 0)
*
*--   main loop
*
	DO I=1,NEVE
*
*--      set electron beam energy
*
	   CALL XSRNDM(RN, 2)
	   ELCE = ELCE0 + ELCDE*SIN(2*PI*RN(1))*SQRT(-2D0*LOG(RN(2)))
*
*--      set collision point
*
	   CALL XSRNDM(RN, 2)
	   COLX   = ELCD/2.355D0*SIN(PI*RN(1))*SQRT(-2*LOG(RN(2)))
	   THETA0 = COLX/COLD
	   THCEFF = COLA*COS(THETA0)
*
*--      set direction of scattered gamma 
*
	   CALL XSRNDM(RN, 2)
	   TEMP = 1D0-2D0*RN(1)
	   IF (TEMP .GE. 0.) THEN
		THETA1 = -ACOS(1D0-(1D0-COS(THCEFF))*TEMP)
	   ELSE
		THETA1 =  ACOS(1D0+(1D0-COS(THCEFF))*TEMP)
	   END IF
*
*--      angle between incident gamma and scattered gamma
*
	   THETA3 = ACOS(SIN(THETA0)*SIN(THETA1)*COS(2D0*PI*RN(2))
     +        +COS(THETA0)*COS(THETA1))
*
*--      generate Gaussian random at half side
*--      to set direction of incident electron
*
	   CALL XSRNDM(RN, 2)
	   TEMP = (COS(ELCAD)-1D0)*SIN(2D0*PI*RN(1))*SQRT(-2D0*LOG(RN(2)))
	   IF (TEMP .LE. 0) THEN
		THETA4 = ACOS(1D0+TEMP)
	   ELSE
		THETA4 = ACOS(1D0-TEMP)
	   END IF
	   CALL XSRNDM(RN, 1)
	   THETA5 = PI - THETA4
	   THETA6 = ACOS(-SIN(THETA4)*COS(2D0*PI*RN(1))*SIN(THETA3)
     +        + COS(THETA4)*COS(THETA3))
*
	   PHTE = PHTE1*(1D0-ELCBT*COS(THETA5))/(1D0-ELCBT*COS(THETA6)
     +        + PHTE1*(1D0-COS(THETA6-THETA5))/ELCE)
	   X1 = -(2D0*ELCGM*PHTE1/ELCM)*(1D0-ELCBT*COS(THETA5))
	   X2 =  (2D0*ELCGM*PHTE /ELCM)*(1D0-ELCBT*COS(THETA6))
	   X3 = ELCR*PHTE/ELCM/X1
	   X4 = 1D0/X1+1D0/X2
	   PHTES = 2D0*X3*X3*(4D0*X4*X4-4D0*X4-(X1/X2+X2/X1))
*
*--      convert to REAL*4
*
	   FPHTE  = PHTE
	   FPHTES = PHTES
*
*--      fill hist
*
	   CALL HF1(DSTHID(6), FPHTE, FPHTES)
*
	END DO
*
	RETURN
	END
