      SUBROUTINE GMMATE
*.
*...GMMATE   Define materials
*.
*. SEQUENCE  : GMLOGI GMMATM
*. CALLS     : GSMATE GSMIXT
*. CALLED    : GMGEOM
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.02
*. CREATED   : 21-Apr-00
*. LAST MOD  : 21-May-00
*.
*. Modification Log.
*. 24-JAN-03   R.Sawada        (V1.04) Added SUS304,SUS316 and Gold.
*. 22-JAN-03   R.Sawada        (V1.03) take into gas xenon.
*. 21-May-00   T.Mashimo       (V1.02) 'LQXE' -> 'XELQ'.
*. 15-May-00   T.Mashimo       (V1.01) Make Nxxxx already negative, if
*.                             appropriate, in the DATA statement.
*.                             Remove the '$' at end of material names.
*. 21-Apr-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "gmlogi.inc"
#include "gmmatm.inc"
#include "lpflag.inc"
#include "xecgeo.inc"
*
      INTEGER NMYLR, NKAPT, NG10,  NPYRX, NPMMA
      INTEGER NGAS1, NGAS2, NGAS4, NCGAS
      INTEGER NQGLS, NSUS304, NSUS316
      REAL    AMYLR(3), ZMYLR(3), WMYLR(3), DMYLR
      REAL    AKAPT(4), ZKAPT(4), WKAPT(4), DKAPT
      REAL    AG10(4),  ZG10(4),  WG10(4),  DG10
      REAL    APYRX(4), ZPYRX(4), WPYRX(4), DPYRX
      REAL    APMMA(3), ZPMMA(3), WPMMA(3), DPMMA
      REAL    AGAS1(3), ZGAS1(3), WGAS1(3), DGAS1
      REAL    AGAS2(3), ZGAS2(3), WGAS2(3), DGAS2
      REAL    AGAS3,    ZGAS3,    DGAS3,    RLGAS3
      REAL    AGAS4(3), ZGAS4(3), WGAS4(3), DGAS4
      REAL    ACGAS(3), ZCGAS(3), WCGAS(3), DCGAS
      REAL    AXE,      ZXE,      DXELQ,    RLXELQ
      REAL    AXEHC,    ZXEHC,    DXEHC,    RLXEHC
      REAL    AQGLS(2), ZQGLS(2), WQGLS(2), DQGLS
      REAL    ASUS304(3), ZSUS304(3), WSUS304(3), DSUS304
      REAL    ASUS316(4), ZSUS316(4), WSUS316(4), DSUS316
      REAL    AGOLD, ZGOLD, DGOLD, RLGOLD
      SAVE    WMYLR, WKAPT, WGAS1, WCGAS
*
*   Composition of Mylar (polyethylene terephthlate, C5H4O2)
*
      DATA NMYLR / -3 /
      DATA AMYLR / 1.01, 12.01, 16.0 /
      DATA ZMYLR / 1.0,   6.0,   8.0 /
      DATA WMYLR / 4.0,   5.0,   2.0 /
      DATA DMYLR / 1.39 /
*
*   Composition of Kapton ( H, C, N, O )
*
      DATA NKAPT  / -4 /
      DATA AKAPT  / 1.01, 12.01, 14.01, 16.0 /
      DATA ZKAPT  / 1.0 ,  6.0 ,  7.0,   8.0 /
*     The following was taken from GOPAL's OPMATE:
**    DATA WKAPT  /   2.,   10.,  2.,    4. /
*     The information from DuPont:
      DATA WKAPT  /  10.,   22.,  2.,    5. /
      DATA DKAPT  / 1.42 /
*
*
*   The following definition of G10 composition has been taken
*   from GOPAL's subroutine OPMATE.            03-Mar-00  T. Mashimo
*
*     Composition parameters for default G10
*     =======================================
*  (Note by GWW - this is the default G10 definition used for the
*   field degraders and the coil epoxy impregnated glass tape used
*   for electrical insulation and mech. strength. It looks like
*   an approximate estimate of the SiO2/epoxy ratio typically used
*   for G10 plates.
*   The actual chemical composition of the coil epoxy impregnated
*   glass tape is under investigation - glass compositions vary
*   substantially (typically only 60% SiO2 !), and epoxies
*   differ depending on application .....)
*
*
*     Definition of G10 transferred from COGEOM to use it also in CD
*
*     (G10 = 60% SiO2 and 40% epoxy : Rev. Mod. Phys. 56 No2(1984)S35
*     (epoxy = 77% C, 16% O, 7% H, by weight : Modern Plastic
*      Encyclopedia 58(1981-82)10A p.18)
*
      DATA NG10   / +4 /
      DATA AG10   / 16.00, 12.01, 28.09,  1.01  /
      DATA ZG10   /  8.00,  6.00, 14.00,  1.00  /
      DATA WG10   /  0.384, 0.308, 0.280, 0.028 /
      DATA DG10   /  1.7 /
*
*   Composition of Pyrex glass
*
*   According to the PDG, main components are
*   80% SiO2 + 12% B2O3 + 5% Na2O.
*   The following weight proportion has been calculated
*   by setting the SiO2 weight is 83%.        06-Mar-00  T. Mashimo
*
      DATA NPYRX  / +4 /
      DATA APYRX  / 10.81, 16.00, 22.99, 28.09  /
      DATA ZPYRX  /  5.00,  8.00, 11.00, 14.00  /
      DATA WPYRX  /  0.037, 0.538, 0.037, 0.388 /
      DATA DPYRX  /  2.23 /
*
*   Composition of Lucite (Plexiglas, Polymethylmethacrylate)
*
      DATA NPMMA  / -3 /
      DATA APMMA  /  1.01, 12.01, 16.00 /
      DATA ZPMMA  /  1.00,  6.00,  8.00 /
      DATA WPMMA  /  8.,    5.,    2.   /
      DATA DPMMA  /  1.16 /
*
*   Composition of "gas 1" (He:Ethane(C2H6) = 50:50), dens. at 20degC
*
      DATA NGAS1  / -3 /
      DATA AGAS1  / 1.01,  4.00, 12.01 /
      DATA ZGAS1  / 1.0,   2.0,   6.0  /
      DATA WGAS1  / 6.0,   1.0,   2.0  /
      DATA DGAS1  / 7.084E-4 /
*
*   Composition of "gas 2" (He:Ethane(C2H6) = 90:10), dens. at 20degC
*
      DATA NGAS2  / +3 /
      DATA AGAS2  / 1.01,  4.00, 12.01 /
      DATA ZGAS2  / 1.0,   2.0,   6.0  /
      DATA WGAS2  / 0.0917, 0.5448, 0.3635 /
      DATA DGAS2  / 2.747E-4 /
*
*   Composition of "gas 3" (pure He), dens. at 20degC
*
      DATA AGAS3  / 4.00 /
      DATA ZGAS3  / 2.0  /
      DATA DGAS3  / 1.663E-4 /
      DATA RLGAS3 / 5.673E+5 /
*
*   Composition of "gas 4" (He:Ethane(C2H6) = 70:30), dens. at 20degC
*
      DATA NGAS4  / +3 /
      DATA AGAS4  / 1.01,  4.00, 12.01 /
      DATA ZGAS4  / 1.0,   2.0,   6.0  /
      DATA WGAS4  / 0.1538, 0.2368, 0.6094 /
      DATA DGAS4  / 4.915E-4 /
*
*   Composition of chamber gas (He + Ethane:C2H6 50/50), at 0degC
*
      DATA NCGAS  / -3 /
      DATA ACGAS  / 1.01,  4.00, 12.01 /
      DATA ZCGAS  / 1.0,   2.0,   6.0  /
      DATA WCGAS  / 6.0,   1.0,   2.0  /
      DATA DCGAS  / 0.760E-3 /
**    DATA DCGAS  / 0.380E-3 /
**    DATA DCGAS  / 1.520E-3 /
*
*   Liquid Xenon
      DATA AXE    / 131.29  /
      DATA ZXE    /  54.00  /
      DATA DXELQ  /   3.057 /
      DATA RLXELQ /   2.77  /
*     
*   SUS Honeycomb core
*
      DATA AXEHC  /  55.845 /
      DATA ZXEHC  /  26.000 /
      DATA DXEHC  /   0.075 /
      DATA RLXEHC / 184.683 /
*
*   Composition of quartz glass (Si and O)
*
      DATA NQGLS  / -2 /
      DATA AQGLS  / 28.09, 16.00 /
      DATA ZQGLS  / 14.,    8.   /
      DATA WQGLS  /  1.,    2.   /
      DATA DQGLS  /  2.20 /

*
*   Composition of SUS-304 (Fe and Cr and Ni)
*
      DATA NSUS304  / +3 /
      DATA ASUS304  / 55.847, 51.996, 58.69 /
      DATA ZSUS304  / 26,  24, 28  /
      DATA WSUS304  / 0.74, 0.18, 0.08/
      DATA DSUS304  / 7.93 /

*
*   Composition of SUS-316 (Fe and Cr and Mo and Ni)
*
      DATA NSUS316  / +4 /
      DATA ASUS316  / 55.847, 51.996, 58.69, 95.94 /
      DATA ZSUS316  / 26, 24, 28, 42/
      DATA WSUS316  / 0.72, 0.16, 0.10, 0.02   /
      DATA DSUS316  / 8.00 /

*
*   Gold
*
      DATA AGOLD    / 196.97  /
      DATA ZGOLD    /  79     /
      DATA DGOLD    /  19.3   /
      DATA RLGOLD   /   0.335 /


*
*--
*-- Define MEG materials
*--
*
*-- General materials
*
      CALL GSMIXT(MAMYLR, 'MYLAR               ',
     +                    AMYLR, ZMYLR, DMYLR, NMYLR, WMYLR)
      CALL GSMIXT(MAKAPT, 'KAPTON              ',
     +                    AKAPT, ZKAPT, DKAPT, NKAPT, WKAPT)
      CALL GSMIXT(MAG10,  'G10                 ',
     +                    AG10,  ZG10,  DG10,  NG10,  WG10)
      CALL GSMIXT(MAPYRX, 'PYREX GLASS         ',
     +                    APYRX, ZPYRX, DPYRX, NPYRX, WPYRX)
      CALL GSMIXT(MAPMMA, 'LUCITE              ',
     +                    APMMA, ZPMMA, DPMMA, NPMMA, WPMMA)
      CALL GSMIXT(MASUS304, 'SUS304              ',
     +                    ASUS304, ZSUS304, DSUS304, NSUS304, WSUS304)
      CALL GSMIXT(MASUS316, 'SUS316              ',
     +                    ASUS316, ZSUS316, DSUS316, NSUS316, WSUS316)
      CALL GSMATE(MAGOLD, 'GOLD                ',
     +     AGOLD, ZGOLD, DGOLD, RLGOLD, 0.0, 0, 0)

*
*-- Gases
*
      CALL GSMIXT(MAGAS1, 'HE 50 + C2H6 50     ',
     +                    AGAS1, ZGAS1, DGAS1, NGAS1, WGAS1)
      CALL GSMIXT(MAGAS2, 'HE 90 + C2H6 10     ',
     +                    AGAS2, ZGAS2, DGAS2, NGAS2, WGAS2)
      CALL GSMATE(MAGAS3, 'PURE HE GAS         ',
     +                    AGAS3, ZGAS3, DGAS3, RLGAS3, 0.0, 0, 0)
      CALL GSMIXT(MAGAS4, 'HE 70 + C2H6 30     ',
     +                    AGAS4, ZGAS4, DGAS4, NGAS4, WGAS4)
*
*-- Chamber gas
*
      CALL GSMIXT(MACGAS, 'CHAMBER GAS         ',
     +                    ACGAS, ZCGAS, DCGAS, NCGAS, WCGAS)
*
*-- Positron timing counters
*
*     The following material definition has been taken from
*     the definition for TB in subroutine OPMATE.
*
      CALL GSMATE(MATFSC, 'TOF SCINTILLATOR    ',
     +                    6.25, 3.4, 1.032, 43., 56.6, 0, 0)
*
*-- Liq. Xe photon detector

      IF(GASXEON .EQ. 1) THEN
         DXELQ  = (5.89E-3)*GASPRES*(273.15/(GASTEMP+273.15)) 
         RLXELQ = 2.77     /GASPRES/(273.15/(GASTEMP+273.15))  
      END IF
      CALL GSMATE(MAXELQ, 'LIQUID XENON        ',
     +                    AXE, ZXE, DXELQ, RLXELQ, 0.0, 0, 0)
      CALL GSMATE(MAXEHC, 'SUS HONEYCOMB CORE  ',
     +                    AXEHC, ZXEHC, DXEHC, RLXEHC, 0.0, 0, 0)
*
      CALL GSMIXT(MAQGLS, 'QUARTZ GLASS        ',
     +                    AQGLS, ZQGLS, DQGLS, NQGLS, WQGLS)
*
  999 CONTINUE
      RETURN
      END
