      SUBROUTINE GUKINE
*.
*...GUKINE   Generate kinematics
*.
*. SEQUENCE  : GCFLAG GCKINE GCONST RCREP  XECGEO XECINT AIST COMPEDG
*. CALLS     : GPRINT GRNDM  GSKINE GSVERT REPORT USKINE HRNDM FUNLUX
*. CALLED    : GTRIG
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.16
*. CREATED   : 06-May-00
*. LAST MOD  : 15-Jul-02
*.
*. Modification Log.
*. 22-Jan-03   R.Sawada        (V1.17) Added cosmic-ray mode and alpha mode
*. 15-Jul-02   K.Ozone         (V1.16) Added ZIN.
*. 04-Jul-02   K.Ozone         (V1.15) Simplified KINE. Mode < -112
*.                             in KINE is not used any longer.
*.                             Gaussian dist. and user-defined
*.                             histogram are available in x, y, z,
*.                             angles, and momentum.
*.                             Kinematics become more flexible.
*.                             PKINE usage changed. MOMTM added.
*.                             Newly DSTHID and DSTSW adapted.
*. 31-Mar-02   K.Ozone         (V1.14) Added inclusion of aistcg.inc
*. 21-Mar-02   K.Ozone         (V1.13) Improved the energy distribution
*.                             of backward scat'd Compton.
*.                             Removed declare.inc inclusion.
*.                             Modified about -3000<IKINE<-2000.
*. 08-Mar-02   K.Ozone         (V1.12) Adapted BSCON switch
*. 23-Feb-02   K.Ozone         (V1.11) Support for random distribution
*.                             in z direction.(ptype on -2000's)
*.                             Good for cosmic ray simuration.
*. 02-Aug-01   K.Ozone         (V1.10) Support for Comptom scat'd gamma
*.                             distributions
*. 01-Feb-01   T.Mashimo       (V1.10) Support for uniform distributions
*.                             for x and y incident positions.
*. 06-May-00   T.Mashimo       (V1.00) 1st version.
*.
*.**********************************************************************
*
#include "geant321/gconst.inc"
#include "geant321/gcflag.inc"
#include "geant321/gckine.inc"
#include "xecgeo.inc"
#include "xecint.inc"
#include "ntuple.inc"
#include "rcrep.inc"
#include "cmpedg.inc"
#include "aistcg.inc"
#include "lpflag.inc"
*
      LOGICAL INIT
      SAVE    INIT
*
      INTEGER NVERT, NT, I
      INTEGER NTRI
      REAL    RNDM(3)
      REAL    VERTEX(3), PABS, PLAB(3),
     +        COSTH1, COSTH2, COSTH, SINTH, PHI
      REAL TTRIG(3), BTRIG(3), TLENGTH
*
      DATA INIT   / .FALSE. /
*
      IF (.NOT. INIT) THEN
         INIT = .TRUE.
      END IF
*
      IF (IKINE .GT. 0 .AND. IKINE .LT. -112) THEN
*
*--      If the 1st parameter of the KINE FFREAD data card is 0,
*--      the user is responsible for generating kinematics
*
         GOTO 500
*
      ELSE
*

         IF(DSTSW(6) .EQ. 5) THEN !cosmic ray mode
            IKINE = -6
            CALL GRNDM(RNDM,2)
            IF (RNDM(1) .LE. 1./3.) THEN
               NTRI = 1
            ELSE IF (RNDM(1) .LE. 2./3.) THEN
               NTRI = 2
            ELSE
               NTRI = 3
            END IF
            
            CALL GRNDM(RNDM,2)
            TTRIG(1) = -5.0 + RNDM(1)*10
            BTRIG(1) = 1.25 + RNDM(2)*10
            
            CALL GRNDM(RNDM,2)
            IF(NTRI .EQ. 1) THEN !front trigger
               TTRIG(3) = 3.0 + RNDM(1)*10
               BTRIG(3) = 3.0 + RNDM(2)*10
            ELSE IF(NTRI .EQ. 2) THEN !middle trigger
               TTRIG(3) = 19.8 + RNDM(1)*10
               BTRIG(3) = 19.8 + RNDM(2)*10
            ELSE IF(NTRI .EQ. 3) THEN !back trigger
               TTRIG(3) = 38.4 + RNDM(1)*10
               BTRIG(3) = 38.4 + RNDM(2)*10
            END IF
            TTRIG(2) = 120.
            BTRIG(2) = -60.
            TLENGTH = SQRT(
     +           (TTRIG(1) - BTRIG(1))**2
     +           +(TTRIG(2) - BTRIG(2))**2
     +           +(TTRIG(3) - BTRIG(3))**2
     +           )
            
            VERTEX(1) = (30. - TTRIG(2))*(TTRIG(1) - BTRIG(1))/(TTRIG(2) 
     +           - BTRIG(2)) + TTRIG(1)
            VERTEX(2) = 30.
            VERTEX(3) = (30. - TTRIG(2))*(TTRIG(3) - BTRIG(3))/(TTRIG(2) 
     +           - BTRIG(2)) + TTRIG(3)
            
            
            CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
            IF (NVERT .LE. 0) THEN
               WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
               CALL REPORT('GUKINE', 1, 'ERROR')
            END IF
            
            PLAB(1) = 3. * (BTRIG(1) - TTRIG(1))/TLENGTH
            PLAB(2) = 3. * (BTRIG(2) - TTRIG(2))/TLENGTH
            PLAB(3) = 3. * (BTRIG(3) - TTRIG(3))/TLENGTH
            
         ELSE IF(DSTSW(6) .EQ. 6) THEN !alpha particle mode
            IKINE = -47
            CALL GRNDM(RNDM, 2)
            IF (RNDM(1) .LT. 0.25) THEN
               NTRI = 1
            ELSE IF  (RNDM(1) .LT. 0.5) THEN
               NTRI = 2
            ELSE IF  (RNDM(1) .LT. 0.75) THEN
               NTRI = 3
            ELSE
               NTRI = 4
            END IF
            CALL GRNDM(RNDM, 3)
            IF (NTRI .EQ. 1) THEN !top
               VERTEX(1) = 0.- 0.05 + 0.1*RNDM(1)
               VERTEX(2) = PALPHA + 0.0002 + 0.0002*RNDM(2)
               VERTEX(3) = 12.4 - 0.05 + 0.1*RNDM(3)
               CALL GRNDM(RNDM, 2)
               PLAB(2) = - RNDM(1) 
               PHI = PI * (2. * RNDM(2))
               SINTH = SQRT(1. - PLAB(2)**2)
               PLAB(1) = COS(PHI) * SINTH
               PLAB(3) = SIN(PHI) * SINTH
            ELSE IF (NTRI .EQ. 2) THEN !left
               VERTEX(1) = PALPHA + 0.0002 + 0.0002*RNDM(1)
               VERTEX(2) = 0.- 0.05 + 0.1*RNDM(2)
               VERTEX(3) = 12.4 - 0.05 + 0.1*RNDM(3)
               CALL GRNDM(RNDM, 2)
               PLAB(1) = - RNDM(1) 
               PHI = PI * (2. * RNDM(2))
               SINTH = SQRT(1. - PLAB(1)**2)
               PLAB(2) = COS(PHI) * SINTH
               PLAB(3) = SIN(PHI) * SINTH
            ELSE IF (NTRI .EQ. 3) THEN !right
               VERTEX(1) = -(PALPHA + 0.0002 + 0.0002*RNDM(1))
               VERTEX(2) = -(0.- 0.05 + 0.1*RNDM(2))
               VERTEX(3) = 12.4 - 0.05 + 0.1*RNDM(3)
               CALL GRNDM(RNDM, 2)
               PLAB(1) =  RNDM(1) 
               PHI = PI * (2. * RNDM(2))
               SINTH = SQRT(1. - PLAB(1)**2)
               PLAB(2) = COS(PHI) * SINTH
               PLAB(3) = SIN(PHI) * SINTH
            ELSE IF (NTRI .EQ. 4) THEN !bottom
               VERTEX(1) = -(0.- 0.05 + 0.1*RNDM(1))
               VERTEX(2) = -(PALPHA + 0.0002 + 0.0002*RNDM(2))
               VERTEX(3) = 12.4 - 0.05 + 0.1*RNDM(3)
               CALL GRNDM(RNDM, 2)
               PLAB(2) =  RNDM(1) 
               PHI = PI * (2. * RNDM(2))
               SINTH = SQRT(1. - PLAB(2)**2)
               PLAB(1) = COS(PHI) * SINTH
               PLAB(3) = SIN(PHI) * SINTH
            END IF
            CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
            IF (NVERT .LE. 0) THEN
               WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
               CALL REPORT('GUKINE', 1, 'ERROR')
            END IF
            
            PLAB(1)= 0.202 * PLAB(1)
            PLAB(2)= 0.202 * PLAB(2)
            PLAB(3)= 0.202 * PLAB(3)
            

         ELSE
*--      A single particle is to be generated.
*--      Its particle code is -IKINE.

*
*
*--      calculate impinging points
*
            DO I=1,3
               CALL GRNDM(RNDM, 2)
               IF (DSTSW(I) .EQ. 1) THEN ! pos-dist. obeys given histogram
                  VERTEX(I) = HRNDM1(DSTHID(I))
               ELSE IF (DSTSW(I) .EQ. 2) THEN ! Gaussian dist.
                  VERTEX(I)=SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +                 PKINE(I*2) + PKINE(I*2-1)
               ELSE             ! flat dist.
                  VERTEX(I) = PKINE(I*2-1)
     +                 +RNDM(1)*(PKINE(I*2)-PKINE(I*2-1))
               END IF
               CALL GSVERT(VERTEX, 0, 0, 0, 0, NVERT)
               IF (NVERT .LE. 0) THEN
                  WRITE(CHREP, '(''GSVERT: NVERT = '', I10)') NVERT
                  CALL REPORT('GUKINE', 1, 'ERROR')
               END IF
            END DO
*     
*--      calculate monemtum
*     
            CALL GRNDM(RNDM, 2)
            IF ((DSTSW(6) .EQ. 1) .OR. (DSTSW(6) .EQ. 3)) THEN ! given histogram
               PABS = HRNDM1(DSTHID(6))
            ELSE IF (DSTSW(6) .EQ. 2) THEN ! Gaussian dist.
               PABS=SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +              MOMTM(2) + MOMTM(1)
            ELSE IF (DSTSW(6) .EQ. 4) THEN
*--      2-poly func approx. func like Klein-Nishina formula(obsolete)
               CALL FUNLUX(FSPACE, XRAN, XRANLEN)
               PABS = XRAN(1)
            ELSE                ! flat energy dist.
               PABS = MOMTM(1)+RNDM(1)*(MOMTM(2)-MOMTM(1))
            END IF
            PABS = PABS*0.001   ! MeV to GeV
*
*--      calculate phi component of momentum
*
            CALL GRNDM(RNDM, 2)
            IF (DSTSW(5) .EQ. 1) THEN ! phi dist. obeys given historgam
               PHI = DEGRAD*HRNDM1(DSTHID(5))
            ELSE IF (DSTSW(5) .EQ. 2) THEN ! Gaussian dist.
               PHI = DEGRAD*(SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +              PKINE(10) + PKINE(9))
            ELSE                ! flat dist.
               PHI = DEGRAD*(PKINE(9) + RNDM(1)*(PKINE(10) - PKINE(9)))
            END IF
*--      calculate theta component of momentum         
            CALL GRNDM(RNDM, 1)
            IF (DSTSW(4) .EQ. 1) THEN ! theta dist. obeys given histogram
               PABS = HRNDM1(DSTHID(4))
            ELSE IF (DSTSW(4) .EQ. 2) THEN ! Gaussian dist. (correct???)
               COSTH1 = COS(PKINE(7)*DEGRAD)
               COSTH2 = ABS(COS((PKINE(7)+PKINE(8))*DEGRAD)-COSTH1)
               COSTH = SQRT(-2.*LOG(RNDM(1)))*COS(2.*PI*RNDM(2))*
     +              COSTH2 + COSTH1
            ELSE                ! flat dist.
               COSTH1 = COS(PKINE(7)*DEGRAD)
               COSTH2 = COS(PKINE(8)*DEGRAD)
               COSTH = COSTH2 + RNDM(1)*( COSTH1 - COSTH2 )
            END IF
            IF (ABS(COSTH) .GT. 1.0) COSTH = SIGN(1.0, COSTH)
            SINTH = SQRT(1. - COSTH*COSTH)
*
*--      calculate 3-momentum
*
            PLAB(1) = PABS * SINTH * COS(PHI)
            PLAB(2) = PABS * SINTH * SIN(PHI)
            PLAB(3) = PABS * COSTH
         END IF
         
         CALL GSKINE(PLAB, -IKINE, NVERT, 0, 0, NT)
         IF (NT .LE. 0) THEN
            WRITE(CHREP, '(''GSKINE: NT = '', I10)') NT
            CALL REPORT('GUKINE', 2, 'ERROR')
         END IF
*
      END IF
*     
 500  CONTINUE
*     
 900  CONTINUE
*
*--   Fill ntuple variables
*
      EVENT = EVENT + 1
      EIN   = PABS
      XIN   = VERTEX(1)
      YIN   = VERTEX(2)
      ZIN   = VERTEX(3)
      THIN  = ACOS(COSTH)
*
*--   Initialize variables in /XECINT/
*
      NINTER = 0
      DO 910 I = 1, 3
         X1INTR(I) = 1.E+15
         X1CONV(I) = 1.E+15
 910  CONTINUE
      DEXESM = 0.0
      DEREST = 0.0
      NDEXE  = 0
      DEXESC = 0.0
*
*-- Call user routine
*
      CALL USKINE
*
*-- Print kinematics
*
      IF (IDEBUG .NE. 0) THEN
         CALL GPRINT('VERT', 0)
         CALL GPRINT('KINE', 0)
      END IF
*
  999 CONTINUE
      RETURN
      END
