      SUBROUTINE XEGINI
*.
*...XEGINI   Initialiation for the geometry of the liquid Xe detector
*.
*. SEQUENCE  : XECGEO RCREP
*. CALLS     : REPORT VZERO
*. CALLED    : GMGEOM
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.01
*. CREATED   : 05-Apr-00
*. LAST MOD  : 05-Sep-01
*.
*. Modification Log.
*. 
*. 05-Sep-01   W.Ootani        (V1.01) Take into account of liquid xenon
*.                             surface.
*. 05-Apr-00   T.Mashimo       (V1.00) First version based on T. Mori's
*.                             INIGEO.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "xecgeo.inc"
#include "rcrep.inc"
*
      INTEGER IX, IY, IW, IP
      REAL    XXENON, YXENON, ZXENON
      REAL    TQGLS
*
      DATA    TQGLS / 0.3 /
*
*-- Check NXPMT, NYPMT, NZPMT, and PMTINT
*
      IF (NXPMT .LE. 0 .OR. NYPMT .LE. 0 .OR. NZPMT .LE. 0) THEN
         WRITE(CHREP, '(''NXPMT, NYPMT, NZPMT must be >0'')' )
         CALL REPORT('XEGINI', 1, 'FATAL')
      END IF
*
      NXYPMT = NXPMT*NYPMT
      NYZPMT = NYPMT*NZPMT
      NZXPMT = NZPMT*NXPMT
      NALPMT = 2*(NXYPMT+NYZPMT+NZXPMT)
*
      IF (NALPMT .GT. MXPMTS) THEN
         WRITE(CHREP,
     +         '(''NALPMT too large: '', I10, '', must be <'', I5)' )
     +         NALPMT, MXPMTS
         CALL REPORT('XEGINI', 2, 'FATAL')
      END IF
*
      IF (PMTINT .LE. 0.0) THEN
         WRITE(CHREP,
     +         '(''Distance between PMTs, PMTINT,  must be >0'')' )
         CALL REPORT('XEGINI', 3, 'FATAL')
      END IF
*
      XXENON = PMTINT*NXPMT
      YXENON = PMTINT*NYPMT
      ZXENON = PMTINT*NZPMT
*
*-- 1 = -X wall
*
      NIJPMT(1,1) = NYPMT               ! # PMT along Y
      NIJPMT(2,1) = NZPMT               ! # PMT along Z
      WALL    (1) = -XXENON/2.          ! -X :PMT wall position
**      WCATH   (1) = -XXENON/2. - TQGLS  ! -X :photo-cathode position
      WCATH   (1) = -XXENON/2.          ! -X :photo-cathode position
*
*-- 2 = +X wall
*
      NIJPMT(1,2) = NYPMT
      NIJPMT(2,2) = NZPMT
      WALL    (2) =  XXENON/2.          ! +X
**      WCATH   (2) =  XXENON/2. + TQGLS  ! +X
      WCATH   (2) =  XXENON/2.          ! +X
*
*-- 3 = -Y wall
*
      NIJPMT(1,3) = NZPMT
      NIJPMT(2,3) = NXPMT
      WALL    (3) = -YXENON/2.          ! -Y :PMT wall position
**      WCATH   (3) = -YXENON/2. - TQGLS  ! -Y :photo-cathode position
      WCATH   (3) = -YXENON/2.          ! -Y :photo-cathode position
*
*-- 4 = +Y wall
*
      NIJPMT(1,4) = NZPMT
      NIJPMT(2,4) = NXPMT
      WALL    (4) =  YXENON/2.          ! +Y
**      WCATH   (4) =  YXENON/2. + TQGLS  ! +Y
      WCATH   (4) =  YXENON/2.          ! +Y
*
*-- 5 = -Z wall
*
      NIJPMT(1,5) = NXPMT
      NIJPMT(2,5) = NYPMT
      WALL    (5) = 0.0                 ! -Z :PMT wall position
**      WCATH   (5) = 0.0        - TQGLS  ! -Z :photo-cathode position
      WCATH   (5) = 0.0                 ! -Z :photo-cathode position
*
*-- 6 = +Z wall
*
      NIJPMT(1,6) = NXPMT
      NIJPMT(2,6) = NYPMT
      WALL    (6) = ZXENON              ! +Z
**      WCATH   (6) = ZXENON     + TQGLS  ! +Z
      WCATH   (6) = ZXENON              ! +Z
*
*
*-- 7 = xenon surface
*
      LEVEL = YXENON*(FILL-0.5)

*-- offset
*
      IJOFFS  (1) = NYPMT
      IJOFFS  (2) = NYPMT
      IJOFFS  (3) = NZPMT
      IJOFFS  (4) = NZPMT
      IJOFFS  (5) = NXPMT
      IJOFFS  (6) = NXPMT
*
      IWOFFS  (1) = 0
      IWOFFS  (2) = IWOFFS(1) + NYZPMT
      IWOFFS  (3) = IWOFFS(2) + NYZPMT
      IWOFFS  (4) = IWOFFS(3) + NZXPMT
      IWOFFS  (5) = IWOFFS(4) + NZXPMT
      IWOFFS  (6) = IWOFFS(5) + NXYPMT
*
*-- PMT positions
*
      CALL VZERO(PMTPOS, 3*NALPMT)
      CALL VZERO(PMTDIR, 3*NALPMT)
*
* -+X walls
*
      DO 100 IW = 1, 2
         DO  90 IX = 1, NIJPMT(1,IW)
            DO  80 IY = 1, NIJPMT(2,IW)
               IP = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
               PMTPOS(1,IP) = WCATH(IW)                          ! X
               PMTPOS(2,IP) = WALL(3) + (FLOAT(IX)-0.5)*PMTINT   ! Y
               PMTPOS(3,IP) = WALL(5) + (FLOAT(IY)-0.5)*PMTINT   ! Z
               IF (IW. EQ. 1) THEN
                  PMTDIR(1,IP) =  1.
               ELSE
                  PMTDIR(1,IP) = -1.
               END IF
               PMTDIR(2,IP) = 0.
               PMTDIR(3,IP) = 0.
   80       CONTINUE
   90    CONTINUE
  100 CONTINUE
*
*  -+Y walls
*
      DO 200 IW = 3, 4
         DO 190 IX = 1, NIJPMT(1,IW)
            DO 180 IY = 1, NIJPMT(2,IW)
               IP = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
               PMTPOS(1,IP) = WALL(1) + (FLOAT(IY)-0.5)*PMTINT   ! X
               PMTPOS(2,IP) = WCATH(IW)                          ! Y
               PMTPOS(3,IP) = WALL(5) + (FLOAT(IX)-0.5)*PMTINT   ! Z
               PMTDIR(1,IP) = 0.
               IF (IW .EQ. 3) THEN
                  PMTDIR(2,IP) =  1.
               ELSE
                  PMTDIR(2,IP) = -1.
               END IF
               PMTDIR(3,IP) = 0.
  180       CONTINUE
  190    CONTINUE
  200 CONTINUE
*
*  -+Z walls
*
      DO 300 IW = 5, 6
         DO 290 IX = 1, NIJPMT(1,IW)
            DO 280 IY = 1, NIJPMT(2,IW)
               IP = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
               PMTPOS(1,IP) = WALL(1) + (FLOAT(IX)-0.5)*PMTINT   ! X
               PMTPOS(2,IP) = WALL(3) + (FLOAT(IY)-0.5)*PMTINT   ! Y
               PMTPOS(3,IP) = WCATH(IW)                          ! Z
               PMTDIR(1,IP) = 0.
               PMTDIR(2,IP) = 0.
               IF (IW .EQ. 5) THEN
                  PMTDIR(3,IP) =  1.
               ELSE
                  PMTDIR(3,IP) = -1.
               END IF
  280       CONTINUE
  290    CONTINUE
  300 CONTINUE
*
* debug
c      WRITE(*,*) 'WALL=',WALL
c      WRITE(*,*) 'WCATH=',WCATH
c      WRITE(*,*) 'i,IP,IW,IX,IY,POSPMT(3),SPMT(3)'
c      K=0
c      DO IW=1,NWALL
c      DO IY=1,NIJPMT(2,IW)
c      DO IX=1,NIJPMT(1,IW)
c        K=K+1
c        IP = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
c        WRITE(*,*) K,IP,IW,IX,IY,(POSPMT(I,IP),I=1,3),(SPMT(I,IP),I=1,3)
c      END DO
c      END DO
c      END DO
*
      RETURN
      END
