      SUBROUTINE XEGPMT
*.
*...XEGPMT   Define geometry of the PMT for the liq. Xe photon detector
*.
*. SEQUENCE  : GCCUTS GCFLAG GCLIST GCONST
*.           : GMMATM RCREP
*. CALLS     : GSATT  GSPOS  GSVOLU REPORT
*. CALLED    : GMGEOM
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.03
*. CREATED   : 17-Mar-00
*. LAST MOD  : 05-Jul-02
*.
*. Modification Log.
*. 05-Jul-02   K.Ozone         (V1.03) Removed QEFF initialization.
*.                             It was moved to lpiffr.F.
*. 23-Feb-02   K.Ozone         (V1.02) QE*CE was changed 0.079 to 0.05.
*. 16-May-00   T.Mashimo       (V1.01) SPxxxx -> VPxxxx.
*. 17-Mar-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
*.   The z-axis of the local coordinate system runs along the axis of
*. the PMT.  The +z is on the side of the quartz glass window.
*.   The volume for the quartz glass window, 'XPWD', is not made
*. a daughter of the volume 'XPMT'.  The caller should put XPMT and
*. XPWD at the same level in the volume tree.  This is to facilitate
*. the tracking of scintillation photons and also to allow putting
*. liquid Xe surrounding the XPWD.
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcflag.inc"
#include "geant321/gclist.inc"
#include "rcrep.inc"
#include "gmmatm.inc"
#include "xecpmt.inc"
*
      INTEGER IVOL, I
      REAL    ZPXPDY
*
*-- Initialization
*
      VPXPWD(1) = 0.000
      VPXPWD(2) = 2.525
      VPXPWD(3) = 0.150
      VPXPMT(1) = 0.000
      VPXPMT(2) = 2.780
      VPXPMT(3) = 1.575
      VPXPSS(2) = VPXPMT(2)
      VPXPSS(1) = VPXPSS(2) - 0.0160
      VPXPSS(3) = 1.475
      VPXPDY(1) = 0.000
      VPXPDY(2) = 2.550
      VPXPDY(3) = 0.0063
      VPXPGL(1) = 0.000
      VPXPGL(2) = 2.260
      VPXPGL(3) = 0.458
      VPXPBS(1) = 0.000
      VPXPBS(2) = 2.240
      VPXPBS(3) = 0.150
      ZPXPWD = VPXPWD(3) + VPXPWD(3)/2.
      ZSXPDY = 1.200
      ZGXPDY = 0.080
      ZPXPGL = -0.700
*
      RCATH  = 4.5/2.
*
*-- Quartz glass window
*
      CALL GSVOLU('XPWD', 'TUBE', TMXPWD, VPXPWD, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 1, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
*-- Mother volume
*
      CALL GSVOLU('XPMT', 'TUBE', TMVACU, VPXPMT, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPMT:'', I8)') IVOL
         CALL REPORT('XEGPMT', 2, 'ERROR')
      END IF
      CALL GSATT('XPMT', 'SEEN', 0)
*
*-- SUS tube
*
      CALL GSVOLU('XPSS', 'TUBE', TMXPSS, VPXPSS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 3, 'ERROR')
      END IF
      CALL GSATT('XPSS', 'SEEN', 1)
      ZPXPSS = VPXPMT(3) - VPXPSS(3)
      CALL GSPOS('XPSS', 1, 'XPMT', 0., 0., ZPXPSS, 0, 'ONLY')
*
*-- Dynodes
*
      CALL GSVOLU('XPDY', 'TUBE', TMXPDY, VPXPDY, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPDY:'', I8)') IVOL
         CALL REPORT('XEGPMT', 4, 'ERROR')
      END IF
      CALL GSATT('XPDY', 'SEEN', 1)
      ZPXPDY = ZSXPDY
      DO 100 I = 1, 13
         CALL GSPOS('XPDY', I, 'XPMT', 0., 0., ZPXPDY, 0, 'ONLY')
         ZPXPDY = ZPXPDY - ZGXPDY
 100  CONTINUE
*
*-- Stem (glass)
*
      CALL GSVOLU('XPGL', 'TUBE', TMXPGL, VPXPGL, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPGL:'', I8)') IVOL
         CALL REPORT('XEGPMT', 5, 'ERROR')
      END IF
      CALL GSATT('XPGL', 'SEEN', 1)
      CALL GSPOS('XPGL', 1, 'XPMT', 0., 0., ZPXPGL, 0, 'ONLY')
*
*-- Base (G10)
*
      CALL GSVOLU('XPBS', 'TUBE', TMXPBS, VPXPBS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPBS', 'SEEN', 1)
      ZPXPBS = -VPXPMT(3) + VPXPBS(3)
      CALL GSPOS('XPBS', 1, 'XPMT', 0., 0., ZPXPBS, 0, 'ONLY')
*
  999 CONTINUE
      RETURN
      END
