      SUBROUTINE XNDKMC
*.
*...XNDKMC   Draw Kamiokande-like unfolded plot:
*.           plot near-wall energy deposits
*.
*. SEQUENCE  : NTUPLE RCREP  XNCGEO XNCPMT XNCINT XNCTRL XNGCOM
*. CALLS     : IGARC  ISELNT ISLN   ISPLCI
*. CALLED    : XNDRAW
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mori
*. VERSION   : 1.01
*. CREATED   : 12-Mar-99
*. LAST MOD  : 03-Jul-02
*.
*. Modification Log.
*. 03-Jul-02   K.Ozone         (V1.01) Change XDEPO to XDEPOS
*. 18-May-00   T.Mashimo       (V1.00) First version based on
*.                             T. Mori's xedkmc.F.  RPMT -> 2.*RCATH.
*.                             XXENON/YXENON/ZXENON -> PMTINT*NXPMT,etc.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "xecint.inc"
#include "ntuple.inc"
#include "xnctrl.inc"
#include "xngcom.inc"
#include "gksenum.inc"
#include "rcrep.inc"
*
      REAL    R1MEV
      INTEGER I
      REAL    X0(2), XC, YC, RC, RMIN, EMEV
*
*-- Set parameters
*
      RMIN  = 2.*RCATH  ! maximum distance of deposits from wall 
      R1MEV = RCATH     ! radius for 1 MeV energy deposit
*
      CALL ISLN(GLSOLI)
*
*-- Select forth view
*
      CALL ISELNT(JTNR4)
*
*-- front face (-Z wall): (+X,+Y) view
*
      X0(1) = 0.  ! origin
      X0(2) = 0.  !
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(3,I)-WALL(5)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF (JLOGP .EQ. 1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
         END IF
         IF (RC .GT. 0.) THEN
            XC = XDEPOS(1,I) + X0(1)     ! +X,+Y
            YC = XDEPOS(2,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
         END IF
      END IF
      END DO
*
*-- rear face (+Z wall): (-X,+Y) view
*
      X0(1) = PMTINT*FLOAT(NXPMT) + PMTINT*FLOAT(NZPMT)  ! origin
      X0(2) = 0.             !
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(3,I)-WALL(6)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF (JLOGP .EQ. 1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
         END IF
         IF(RC.GT.0.) THEN
            XC = -XDEPOS(1,I) + X0(1)     ! -X,+Y
            YC =  XDEPOS(2,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
         END IF
      END IF
      END DO
*
*-- side 1 (-X wall): (-Z,+Y) view
*
      X0(1) = -PMTINT*FLOAT(NXPMT)/2.     ! origin
      X0(2) = 0.             !
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(1,I)-WALL(1)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF(JLOGP.EQ.1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
         END IF
         IF (RC .GT. 0.) THEN
            XC = -XDEPOS(3,I) + X0(1)     ! -Z,+Y
            YC =  XDEPOS(2,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
         END IF
      END IF
      END DO
*
*-- side 2 (+X wall): (+Z,+Y) view
*
      X0(1) =  PMTINT*FLOAT(NXPMT)/2.     ! origin
      X0(2) = 0.             !
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(1,I)-WALL(2)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF (JLOGP .EQ. 1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
         END IF
         IF(RC.GT.0.) THEN
            XC =  XDEPOS(3,I) + X0(1)     ! +Z,+Y
            YC =  XDEPOS(2,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
         END IF
      END IF
      END DO
*
*-- side 3 (-Y wall): (+X,-Z) view
*
      X0(1) = 0.              ! origin
      X0(2) = -PMTINT*FLOAT(NYPMT)/2.      !
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(2,I)-WALL(3)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF (JLOGP .EQ. 1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
         END IF
         IF (RC .GT. 0.) THEN
            XC =  XDEPOS(1,I) + X0(1)     ! +X,-Z
            YC = -XDEPOS(3,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
          END IF
      END IF
      END DO
*
*-- side 4 (+Y wall): (+X,+Z) view
*
      X0(1) = 0.              ! origin
      X0(2) =  PMTINT*FLOAT(NYPMT)/2.
      DO I = 1, NDEPO
      IF (ABS(XDEPOS(2,I)-WALL(4)) .LT. RMIN) THEN
         EMEV = XDEPOS(4,I)*1000.  ! XDEPOS(4) in GeV
         IF      (EMEV .GE. 5.) THEN
            CALL ISPLCI(2)          ! > 5MeV red
         ELSE IF (EMEV .GE. 1.) THEN
            CALL ISPLCI(5)          ! > 1MeV yellow
         ELSE IF (EMEV .GE. 0.5) THEN
            CALL ISPLCI(3)          ! > 0.5 MeV green
         ELSE IF (EMEV .GE. 0.1) THEN
            CALL ISPLCI(7)          ! > 0.1 MeV light blue
         ELSE
            CALL ISPLCI(1)
         END IF
         IF (JLOGP .EQ. 1) THEN
            RC = ALOG10(EMEV*1000.)/3.*R1MEV
         ELSE
            RC = SQRT(EMEV)*R1MEV
          END IF
         IF (RC .GT. 0.) THEN
            XC =  XDEPOS(1,I) + X0(1)     ! +X,+Z
            YC =  XDEPOS(3,I) + X0(2)     ! 
            CALL IGARC(XC, YC, RC, RC, 0., 0.)
         END IF
      END IF
      END DO
*
      RETURN
      END
