      SUBROUTINE XSHITP(X, V,
     +                  IWALL, IFACE, XHIT, DIST, IHIT, IADDR, IERR)
*.
*...XSHITP   Locate the PMT that will detect this scinti. photon
*.
*. INPUT     : X(1-3)    position of the photon
*. INPUT     : V(1-3)    direction of the photon
*. OUTPUT    : IWALL     =1: hits +-X wall, =2: +-Y wall, =3: +-Z wall
*                        
*. OUTPUT    : IFACE     =1: -X/Y/Z side, =2: +X/Y/Z side
*. OUTPUT    : XHIT      hit position on the wall
*. OUTPUT    : DIST      distance that photon travels to reach PMT
*. OUTPUT    : IHIT      =1: hits a photo-cathode, =0: otherwise 
*.                       =2: hits xenon surface
*. OUTPUT    : IADDR     address of the hit PMT
*. OUTPUT    : IERR      =0: no error
*.
*     . SEQUENCE  : XECGEO XECPMT RCREP
*. CALLS     : REPORT
*. CALLED    : XSTRAK
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.01
*. CREATED   : 07-Apr-00
*. LAST MOD  : 06-Sep-01
*.
*. Modification Log.
*. 06-Sep-01   W.Ootani        (V1.01) Take into account of liquid xenon
*.                             surface.
*. 07-Apr-00   T.Mashimo       (V1.00) 1st version based on T. Mori's
*.                             HITPMT.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "xecsci.inc"
#include "rcrep.inc"
*
      INTEGER IHIT, IADDR, IFACE, IWALL, IERR
      REAL    X(3), V(3), DIST, XHIT(3)
*
      INTEGER IW, I, J, K, IXYZ(2), IAXIS(2,3)
      REAL    T(3), TMIN, DX(3), OFF, OFFPMT(2), R2
      DATA    IAXIS / 2,3, 3,1, 1,2 /
*


      IERR = 0
*
      IW = 0
      IWALL = 0
      IFACE = 0
      IADDR = 0
      TMIN  = 1.E+9

*-    RFLG =1:photon in xenon =0:photon in vacuum  


      DO 100 I = 1, 3
         IF (V(I) .LT. 0.) THEN ! towards -X/Y/Z
            J = 2*I - 1
            T(I) = ABS((WCATH(J)-X(I))/V(I))
         ELSE IF (V(I) .GT. 0.) THEN ! towards +X/Y/Z
            J = 2*I
            T(I) = ABS((WCATH(J)-X(I))/V(I))
         ELSE
            T(I) = 1.E+20
         END IF
         IF (T(I) .LT. TMIN) THEN
            IW = J
            IWALL = I
            TMIN = T(I)
         END IF
 100  CONTINUE

*-    check if photon hits xenon surface
      T(2) = 1.E+20
      IF (((RFLG .NE. 0) .and. (V(2) .GT. 0))
     +     .or. ((RFLG .EQ. 0) .and. (V(2) .LT. 0))) THEN 
         T(2) = ABS((LEVEL-X(2))/V(2))
      END IF

      IHIT = 1

      IF (T(2) .LT. TMIN) THEN  ! if photon hit xenon surface
         TMIN = T(2)
         IHIT = 2 
*         write(*,*)'photon hit xenon surface in xshitp'
      END IF
*      write(*,*)'photon not hit xenon surface in xshitp'

      
*     
      IF (IHIT .NE. 2) THEN
         IF (IWALL .EQ. 0) THEN
            WRITE(CHREP, '(''Photon does not hit any wall'')')
            CALL REPORT('XSHITP', 1, 'ERROR')
            IHIT = -1
            IERR = 2
            RETURN
         END IF
*
         IF (V(IWALL) .LT. 0.) THEN
            IFACE = 1
         ELSE
            IFACE = 2
         END IF
         DO 200 I = 1, 3
            DX(I) = V(I)*TMIN
            XHIT(I) = X(I) + DX(I)
 200     CONTINUE
         IF (ABS(DX(1)) .LT. 1.E-6) DX(1) = 0.
         IF (ABS(DX(2)) .LT. 1.E-6) DX(2) = 0.
         IF (ABS(DX(3)) .LT. 1.E-6) DX(3) = 0.
         DIST = SQRT(DX(1)**2 + DX(2)**2 + DX(3)**2)
*
         IHIT = 1
         DO 300 K = 1, 2        !e.g. for IWALL=z : 
            I = IAXIS(K, IWALL) !       I=x,y (for k=1,2)
            OFF = XHIT(I) - WALL(2*I-1) !       OFF = xhit - xwall(-)
            IXYZ(K) = INT(OFF/PMTINT) + 1
            OFFPMT(K) = AMOD(OFF, PMTINT) ! hit position inside 'PMT unit'
 300     CONTINUE
         IADDR = IXYZ(1) + (IXYZ(2)-1)*IJOFFS(IW) + IWOFFS(IW)
*
         R2 = (OFFPMT(1) - PMTINT/2.)**2 + (OFFPMT(2) - PMTINT/2.)**2
         IF (R2 .GT. RCATH*RCATH) IHIT = 0 ! hit outside PMT; RCATH=radius
         
      ELSE                      ! if photon hits xenon surface
   
         DO 400 I = 1, 3
            DX(I) = V(I)*TMIN
            XHIT(I) = X(I) + DX(I)
 400     CONTINUE
         IF (ABS(DX(1)) .LT. 1.E-6) DX(1) = 0.
         IF (ABS(DX(2)) .LT. 1.E-6) DX(2) = 0.
         IF (ABS(DX(3)) .LT. 1.E-6) DX(3) = 0.
         DIST = SQRT(DX(1)**2 + DX(2)**2 + DX(3)**2)

      END IF
*
*-- FUNNY IADDR value?
*
      IF (IHIT .EQ. 1) THEN
         IF (IADDR .LE. 0 .OR. IADDR .GT. NALPMT) THEN
            WRITE(CHREP, '(''Funny PMT number:'', 5I10)')
     +            IADDR, IWALL, IFACE, IXYZ
            CALL REPORT('XSHITP', 2, 'ERROR')
            WRITE(CHREP, '(''  XHIT = '', 3F10.3)')
     +            XHIT
            CALL REPORT('XSHITP', 3, 'ERROR')
            IERR = 1
         END IF
      END IF
*
  999 CONTINUE
      RETURN
      END
