      SUBROUTINE XSINIT
*.
*...XSINIT   Initialization for scintillation light tracking in liq. Xe
*.
*. SEQUENCE  : GCONST
*.           : RCREP  XECGEO XECPMT XECSCI
*. CALLS     : XSRNDQ
*. CALLED    : UGINIT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.06
*. CREATED   : 07-Apr-00
*. LAST MOD  : 24-Jul-02
*.
*. Modification Log.
*. 24-Jul-02   K.Ozone         (V1.06) Changed CTHETA to CRAGXV and
*.                             introduced CRAGXQ for quartz reflection
*.                             loop not to share the critical angle
*.                             variable CTHETA with Xe surface loop in
*.                              xstrak.F.
*. 15-Jul-02   K.Ozone         (V1.05) Changed default value of PMTQEF.
*. 05-Jul-02   K.Ozone         (V1.04) Changed QEFF to PMTQEF.
*. 03-Jul-02   K.Ozone         (V1.03) added QABSON switch REPORT
*. 16-Mar-02   K.Ozone         (V1.02) added initialization of CTHETA
*.                             and reports for reflection on quartz
*.                             window and LXe surface level
*. 17-Jan-01   T.Mashimo       (V1.01) Support LRAYL=2.
*. 07-Apr-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "xecsci.inc"
#include "rcrep.inc"
*
      INTEGER ISEQ
*
      IF (ISCTRK .LE. 0) THEN
         WRITE(CHREP, '(''Xe scintillation light tracking: OFF'')' )
         CALL REPORT('XSINIT', 1, 'INFO')
         GOTO 900
      END IF
*
      WRITE(CHREP, '(''Xe scintillation light tracking: ON'')')
      CALL REPORT('XSINIT', 1, 'INFO')
*
*-- Initialize variables in /XECSCI/ after reading FFREAD cards
*
      VLIGHT = CLIGHT/RFRIDX
      CRAGXV = ASIN(1./RFRIDX)
      IF(QRFIDX .GE. RFRIDX) THEN
         CRAGXQ = ASIN(QRFIDX/RFRIDX)
      ELSE
         CRAGXQ = ASIN(1.)
      END IF
*
*-- Initialize the random number generator
*
      IF (NSRNDM(2) .NE. 0) THEN
         CALL XSRNDQ(NSRNDM(1), NSRNDM(2), 1, 'S')
      ELSE IF (NSRNDM(1) .GT. 0) THEN
         ISEQ = NSRNDM(1)
         CALL XSRNDQ(NSRNDM(1), NSRNDM(2), ISEQ, 'Q')
         CALL XSRNDQ(NSRNDM(1), NSRNDM(2), ISEQ, 'S')
      END IF
*
*-- Print parameters
*
      WRITE(CHREP,
     +     '(''dE/dx per scintillation photon: '', F10.3, '' eV'')' )
     +      ESCINT*1.E9
      CALL REPORT('XSINIT', 2, 'INFO')
*
      IF (IPOISN .EQ. 0) THEN
         WRITE(CHREP,
     +        '(''Poisson distribution in light generation: OFF'')' )
      ELSE
         WRITE(CHREP,
     +        '(''Poisson distribution in light generation: ON'')' )
      END IF
      CALL REPORT('XSINIT', 3, 'INFO')
*
      WRITE(CHREP, '(''Refractive index of liquid Xe: '', F10.3)' )
     +      RFRIDX
      CALL REPORT('XSINIT', 4, 'INFO')
*
      IF (LRAYL .EQ. 0) THEN
         WRITE(CHREP, '(''Rayleigh scattering: OFF'')' )
         CALL REPORT('XSINIT', 5, 'INFO')
      ELSE IF (LRAYL .EQ. 1) THEN
         WRITE(CHREP,
     +        '(''Rayleigh scattering: ON (isotropic)'',
     +         F10.3, '' cm'')' )
     +         DRAYL
         CALL REPORT('XSINIT', 5, 'INFO')
      ELSE IF (LRAYL .GE. 2) THEN
         WRITE(CHREP,
     +        '(''Rayleigh scattering: ON (1+(cos(theta)**2))'',
     +         F10.3, '' cm'')' )
     +         DRAYL
         CALL REPORT('XSINIT', 5, 'INFO')
      END IF
*
      IF (IABSO .EQ. 0) THEN
         WRITE(CHREP, '(''Light absorption: OFF'')' )
         CALL REPORT('XSINIT', 6, 'INFO')
      ELSE
         WRITE(CHREP,
     +        '(''Light absorption: ON'', F10.3, '' cm'')' )
     +         DABSO
         CALL REPORT('XSINIT', 6, 'INFO')
      END IF
*
      IF (IREFL .EQ. 0) THEN
         WRITE(CHREP, '(''Light reflection at wall: OFF'')' )
         CALL REPORT('XSINIT', 7, 'INFO')
      ELSE
         WRITE(CHREP,
     +        '(''Light reflection at wall: ON, eff. = '', F10.3)' )
     +         EREFL
         CALL REPORT('XSINIT', 7, 'INFO')
      END IF
*
      WRITE(CHREP, '(''Photo-cathode radius: '', F10.3)' ) RCATH
      CALL REPORT('XSINIT', 8, 'INFO')
*
      IF (PMTQEF .EQ. 0.0) THEN
         IF (QABSON .EQ. 1) THEN
            PMTQEF = 0.0631
         ELSE
            PMTQEF = 0.05
         END IF
      END IF
      WRITE(CHREP, '(''Quantum eff. * transmission prob.: '', F10.3)' )
     +     PMTQEF
      CALL REPORT('XSINIT', 9, 'INFO')
*
      IF (QREFON .EQ. 1) THEN
         WRITE(CHREP, '(''Reflection on quartz window: ON'')' )
      ELSE
         WRITE(CHREP, '(''Reflection on quartz window: OFF'')' )
      END IF
      CALL REPORT('XSINIT', 10, 'INFO')
*
      IF (QABSON .NE. 0) THEN
         WRITE(CHREP, '(''Absorption on quartz window: ON'')' )
      ELSE
         WRITE(CHREP, '(''Absorption on quartz window: OFF'')' )
      END IF
      CALL REPORT('XSINIT', 11, 'INFO')
*
      IF (FILL .LT. 1.) THEN
         WRITE(CHREP, '(''Xe surface level: '', F7.3, '' %'')' )
     +        FILL*100
         CALL REPORT('XSINIT', 12, 'INFO')
      END IF
*
  900 CONTINUE
*
  999 CONTINUE
      RETURN
      END
