      SUBROUTINE XSTRAK(DEPOX)
*.
*...XSTRAK   Genereate and transport scintillation light in liq. Xe
*.
*. INPUT     : DEPOX(1-3)  position of energy deposit (x,y,z)
*. INPUT     : DEPOX(4)    deposited energy in GeV
*.
*. SEQUENCE  : GCONST
*.           : RCREP  XECGEO XECPMT XECSCI
*. CALLS     : REPORT XSPOIS XSRNDM XSHITP
*. CALLED    : GUOUT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.10
*. CREATED   : 11-Apr-00
*. LAST MOD  : 24-Jul-02
*.
*. Modification Log.
*. 04-Feb-03   R.Sawada        (V1.12) enabled to scintillate outside WALL(I)
*. 22-Jan-03   R.Sawada        (V1.11) Modidied quartz absorption.
*.                             TRANS is value against 2mmm quartz,
*.                             but actuallly PMT quartz window is 2.5mm.
*. 24-Jul-02   K.Ozone         (V1.10) changed CTHETA in quartz
*.                             refrection loop to CRAGXQ, while in Xe
*.                             surface loop CTHETA to CRAGXV.
*. 20-Jul-02   K.Ozone         (V1.09) TRANS array was multipled by 0.01,
*.                             that is, changed percentage to ratio.
*.                             It was a big mistake.
*. 06-Jul-02   K.Ozone         (V1.08) Fixed a fatal bug which occurs
*.                             infinty loop between top face and Xe
*.                             surface because photon position vector X
*.                             are not set to hitted point in quartz
*.                             reflection loop.
*.                             Improved absorption loop to introduce
*.                             wave length.
*.                             Changed XDEPO to DEPOX in order to
*.                             avoid confusion with XDEPO in ntuple.
*.                             Added wavelength-depended Rayleigh
*.                             scattering. (LRAYL = 3)
*.                             Changed QEFF to PMTQEF.
*. 02-Jul-02   K.Ozone         (V1.07) QABSON switch for V1.06
*. 01-Jul-02   R.Sawada        (V1.06) Absorption on PMT quartz window
*. 16-Mar-02   K.Ozone         (V1.05) Modified to speed up in loops
*. 21-Feb-02   R.Sawada        (V1.04) Support for photon reflection on
*.                             quartz window
*. 05-Sep-01   W.Ootani        (V1.03) Take into account of liquid xenon
*.                             surface.
*.                             But filled with vacuum instead of Gas Xe
*.                             over liquid Xe surface.
*. 30-Jan-01   T.Mashimo       (V1.02) Fix two bugs;
*.                             (1) When I modified scsim.F, I forgot
*.                             to remove some debris of T. Mori's code;
*.                             simulation of light absorption should
*.                             have been wrong.  (Hopefully nobody has
*.                             ever switched on light absorption.)
*.                             (2) For "XESCRAYL 2", the photon position
*.                             was not advanced when scattering takes
*.                             place.
*. 18-Jan-01   T.Mashimo       (V1.01) Support for "XESCRAYL 2".
*. 11-Apr-00   T.Mashimo       (V1.00) 1st version based on T. Mori's
*.                             SCSIM.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "xecsci.inc"
#include "xecint.inc"
#include "rcrep.inc"
*
      REAL    DEPOX(5)
*
      INTEGER NPH, IPH,
     +     IWALL, IFACE, IHIT, IADDR, IERR,
     +     IW, ISCAT, I, K
      REAL    AVNPH
      REAL    X(3), RN(2), CTH, STH, CPH, SPH, V(4), XHIT(3), DIST,
     +     XABSO, XRAYL
      REAL    TH1, TH2
      REAL    CTH1, STH1, CTH2, STH2, THETA1,THETA2
      REAL    RFLCTC ! refractance of quartz
      REAL    TRNSMT ! transmittance of PMT window
      REAL    KK
      REAL    VNEW(3)
      LOGICAL ROTATE
      INTEGER DIRCT
      REAL    DPHAI,DSINTH
      INTEGER IAXIS(2,3), IXYZ(2)
      REAL    OFF
*
      INTEGER IDX, IDXMIN, IDXMAX
      REAL    OFFPMT(2), R2
      REAL    WLEN
      REAL    WAVRAT(53), WAVLEN(53), TRANS(53)
      DATA    WAVRAT / ! integrated ratio table for Xe scinti wave length
     +     0.001993134758, 0.005757944857, 0.011294430296,
     +     0.018381131658, 0.027018048943, 0.037205182150,
     +     0.049385450116, 0.062673015170, 0.079503930905,
     +     0.100764034991, 0.124903111505, 0.150592403942,
     +     0.178274831137, 0.207728933673, 0.239176170967,
     +     0.272173624183, 0.305171077400, 0.339497287122,
     +     0.374487875097, 0.409478463072, 0.444247591629,
     +     0.478573801351, 0.512235632820, 0.545011626619,
     +     0.576901782748, 0.607906101207, 0.637803122578,
     +     0.666814306278, 0.694275274056, 0.720407485328,
     +     0.745210940095, 0.769128557192, 0.790831580113,
     +     0.810984387111, 0.829808437604, 0.847303731591,
     +     0.863470269073, 0.877865131215, 0.892481452774,
     +     0.908869449673, 0.923707230650, 0.936441147160,
     +     0.947514118038, 0.957701251246, 0.966781087366,
     +     0.974753626398, 0.980954490090, 0.985826597276,
     +     0.989591407375, 0.992470379803, 0.994906433396,
     +     0.997563946407, 1.0 /
      DATA    WAVLEN / ! wavelength
     +     184.2169, 183.0120, 182.2892, 
     +     181.3253, 180.6024, 180.1205, 
     +     179.8795, 179.6386, 178.6747, 
     +     177.7108, 177.2289, 176.9880, 
     +     176.5060, 175.7831, 175.3012, 
     +     174.5783, 174.3373, 174.0964, 
     +     173.6145, 173.1325, 172.4096, 
     +     171.9277, 171.6867, 171.2048, 
     +     170.7229, 170.2410, 169.5181, 
     +     169.0361, 168.3133, 167.8313, 
     +     167.3494, 167.1084, 166.3855, 
     +     165.9036, 165.1807, 164.4578, 
     +     164.2169, 163.7349, 163.4940, 
     +     163.2530, 163.0120, 162.7711, 
     +     162.5301, 162.2892, 162.0482, 
     +     161.3253, 160.3614, 159.8795, 
     +     159.1566, 157.9518, 156.5060, 
     +     155.3012, 154.3373 /
      DATA    TRANS / ! transmittance against 2mmt quartz (by K.Terasawa)
     +     0.91422, 0.91301, 0.91229, 
     +     0.91133, 0.91060, 0.91012, 
     +     0.90976, 0.90928, 0.90702, 
     +     0.90384, 0.90192, 0.90095, 
     +     0.89902, 0.89592, 0.89351, 
     +     0.88989, 0.88869, 0.88748, 
     +     0.88430, 0.88093, 0.87410, 
     +     0.86928, 0.86687, 0.86205, 
     +     0.85723, 0.85241, 0.84374, 
     +     0.83747, 0.82533, 0.81325, 
     +     0.79398, 0.78434, 0.75542, 
     +     0.73344, 0.68429, 0.62429, 
     +     0.60309, 0.56067, 0.53947, 
     +     0.51826, 0.49706, 0.47586, 
     +     0.45465, 0.43345, 0.41224, 
     +     0.34863, 0.26380, 0.22212, 
     +     0.16284, 0.06759, 0.01259, 
     +     0.00220, 0.00034 /

      DATA  IAXIS / 2,3, 3,1, 1,2 /
*
*-- Determine number of scintillation photons to be generated
*
      IF (DEPOX(1) .GT. WALL(1) .AND.
     +     DEPOX(1) .LT. WALL(2) .AND.
     +     DEPOX(2) .GT. WALL(3) .AND.
     +     DEPOX(2) .LT. WALL(4) .AND.
     +     DEPOX(3) .GT. WALL(5) .AND.
     +     DEPOX(3) .LT. WALL(6)) THEN
         AVNPH = DEPOX(4)/ESCINT*PMTQEF ! == # of photo-electrons
      ELSE
         IF (DEPOX(1) .LE. WALL(1)) THEN
            IWALL = 1
         ELSE IF(DEPOX(1) .GE. WALL(2)) THEN
            IWALL = 1
         ELSE IF(DEPOX(2) .LE. WALL(3)) THEN
            IWALL = 2
         ELSE IF(DEPOX(2) .GE. WALL(4)) THEN
            IWALL = 2
         ELSE IF(DEPOX(3) .LE. WALL(5)) THEN
            IWALL = 3
         ELSE IF(DEPOX(3) .GE. WALL(6)) THEN
            IWALL = 3
         END IF
         DO 30 K = 1, 2         !e.g. for IWALL=z : 
            I = IAXIS(K, IWALL) !       I=x,y (for k=1,2)
            OFF = DEPOX(I) - WALL(2*I-1) !       OFF = xhit - xwall(-)
            IXYZ(K) = INT(OFF/PMTINT) + 1
            OFFPMT(K) = AMOD(OFF, PMTINT) ! hit position inside 'PMT unit'
 30      CONTINUE
         R2 = (OFFPMT(1) - PMTINT/2.)**2 + (OFFPMT(2) - PMTINT/2.)**2
         IF (R2 .GT. RCATH*RCATH) THEN ! outside PMT; RCATH=radius
            AVNPH = DEPOX(4)/ESCINT*PMTQEF ! == # of photo-electrons
         ELSE !inside PMT
            GOTO 999
         END IF
      END IF
*     !  DESTEP > keV by GUSTEP
      PEGEN = PEGEN + AVNPH
      IF (IPOISN .EQ. 1) THEN
         CALL XSPOIS(AVNPH, NPH, 1)
      ELSE
         NPH = NINT(AVNPH)
      END IF
      NPEGEN = NPEGEN + NPH
*
      DO 500 IPH = 1, NPH
*
         RFLG = 1 ! initial photons are in xenon
*
         X(1) = DEPOX(1)
         X(2) = DEPOX(2)
         X(3) = DEPOX(3)
*     
*-- define wave length to evaluate absorption in quartz and contaminated Xe
*

         IDXMIN = 1
         IDXMAX = 53
         CALL XSRNDM(RN, 1)
*

         IDX = 1
 100     IF (RN(1) .LE. WAVRAT(IDX)) GO TO 150
         IDX = IDX +1
         GO TO 100
         
*
 150     WLEN = WAVLEN(IDX)
*
 200     CONTINUE
*
         CALL XSRNDM(RN, 2)
         CTH = 2.*RN(1) - 1.
         IF (ABS(CTH) .GE. 1.) THEN
            CTH = SIGN(1., CTH)
            STH = 0.
         ELSE
            STH = SQRT(1.0 - CTH**2)
         END IF
         V(1) = STH*COS(TWOPI*RN(2))  ! photon direction
         V(2) = STH*SIN(TWOPI*RN(2))  !
         V(3) = CTH                   !
         V(4) = VLIGHT                !
*
 300     CONTINUE

         IF (((X(1) .LE. WALL(1)) .AND. (V(1) .LT. 0.)) .OR.
     +        ((X(1) .GE. WALL(2)) .AND. (V(1) .GT. 0.)) .OR.
     +        ((X(2) .LE. WALL(3)) .AND. (V(2) .LT. 0.)) .OR.
     +        ((X(2) .GE. WALL(4)) .AND. (V(2) .GT. 0.)) .OR.
     +        ((X(3) .LE. WALL(5)) .AND. (V(3) .LT. 0.)) .OR.
     +        ((X(3) .GE. WALL(6)) .AND. (V(3) .GT. 0.))) THEN 
            GOTO 500            !absorbed
         END IF
*     
*--   Transport scintillation light to the wall
*     
         CALL XSHITP(X, V, IWALL, IFACE, XHIT, DIST, IHIT, IADDR, IERR)
         IF (IERR .NE. 0) GO TO 500 ! skip if error
*
         ISCAT = 0
         XABSO = 1.E10
         XRAYL = 1.E10
         CALL XSRNDM(RN, 2)
         IF (IABSO .GE. 1) XABSO = -DABSO*ALOG(RN(1))
         IF (LRAYL .GE. 1) THEN
            XRAYL = -DRAYL*ALOG(RN(2))
            IF (LRAYL .EQ. 3) THEN
               XRAYL = XRAYL*(WLEN/175.)**4
            END IF
         END IF
*
         IF(RFLG .EQ. 1) THEN   ! if photon inside xenon
*     
            IF (XRAYL .GE. XABSO) THEN
               IF (DIST .GT. XABSO) GO TO 500 ! absorbed
            ELSE
               IF (DIST .GT. XRAYL) THEN ! scattered
                  ISCAT = 1
                  IF (LRAYL .EQ. 1) THEN
                     X(1) = X(1) + XRAYL*V(1)
                     X(2) = X(2) + XRAYL*V(2)
                     X(3) = X(3) + XRAYL*V(3)
                     GO TO 200
                  ELSE IF (LRAYL .GE. 2) THEN
 320                 CONTINUE
                     CALL XSRNDM(RN, 2)
                     CTH = 2.*RN(1) - 1.
                     IF (ABS(CTH) .GE. 1.) CTH = SIGN(1., CTH)
                     STH = SQRT(1.0 - CTH**2)
                     IF (RN(2) .GT. 0.5*(1.+CTH**2)) GO TO 320
*
                     CALL XSRNDM(RN, 1)
                     CPH = COS(TWOPI*RN(1))
                     SPH = SIN(TWOPI*RN(1))
                     VNEW(1) = STH*CPH
                     VNEW(2) = STH*SPH
                     VNEW(3) = CTH
                     CALL GFANG(V, CTH, STH, CPH, SPH, ROTATE)
                     IF (ROTATE) CALL GDROT(VNEW, CTH, STH, CPH, SPH)
                     X(1) = X(1) + XRAYL*V(1)
                     X(2) = X(2) + XRAYL*V(2)
                     X(3) = X(3) + XRAYL*V(3)
                     CALL UCOPY(VNEW, V, 3)
                     GO TO 300
                  END IF
               END IF
            END IF
         END IF

        
*

*
*-- If it hits the photo-cathode of a PMT
*
         IF (IHIT .EQ. 1) THEN
            IW = 2*IWALL + IFACE - 2 ! wall number = 1-6
*
*--   forbid any hits from the back of PMT
*
            IF ((IW .EQ. 1 .AND. V(1) .GT. 0)
     +           .OR. (IW .EQ. 2 .AND. V(1) .LT. 0)
     +           .OR. (IW .EQ. 3 .AND. V(2) .GT. 0)
     +           .OR. (IW .EQ. 4 .AND. V(2) .LT. 0)
     +           .OR. (IW .EQ. 5 .AND. V(3) .GT. 0)
     +           .OR. (IW .EQ. 6 .AND. V(3) .LT. 0)) THEN
               GO TO 500
            END IF
*
*--- which face does the photon hit on ?
*--- 1:right, 2:left, 3:top, 4:bottom, 5:front, 6:back
*
            IF (QREFON .EQ. 1) THEN
               X(1) = XHIT(1)
               X(2) = XHIT(2)
               X(3) = XHIT(3)
               DIRCT = INT((IW-1)/2+1)
               CTH1 = ABS(V(DIRCT))
               IF (ACOS(CTH1) .GT. CRAGXQ) THEN ! total reflection
                  V(DIRCT) = -V(DIRCT)
                  GO TO 300
               ELSE
                  STH1 = SQRT(1-CTH1*CTH1)
                  STH2 = STH1*(RFRIDX/QRFIDX) ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
                  THETA1 = ACOS(CTH1)
                  THETA2 = ACOS(CTH2)
                  RFLCTC = (           
     +                 (SIN(THETA1 -THETA2)
     +                 / SIN(THETA1 + THETA2))**2
     +                 + (TAN(THETA1 - THETA2)
     +                 / TAN(THETA1 + THETA2))**2
     +                 )*0.5 !Fresnel reflection (no polarization)
                  CALL XSRNDM(RN, 1)
                  IF (RN(1) .LT. RFLCTC) THEN
                     V(DIRCT) = -V(DIRCT) ! normal reflection
                     GO TO 300
                  END IF
               END IF
            END IF
            IF (QABSON .EQ. 1) THEN
               IF (QREFON .EQ. 0) THEN
                  DIRCT = INT((IW-1)/2+1)
                  STH2 = SQRT(1-V(DIRCT)*V(DIRCT))*(RFRIDX/QRFIDX) ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
               END IF
               CALL XSRNDM(RN, 1)
               TRNSMT = (TRANS(IDX) ** (2.5/(2.*CTH2)))! Ryu's equation
               IF (RN(1) .GE. TRNSMT) GO TO 500 ! absorbed in quartz
            END IF
*
 330        NPEALL        = NPEALL + 1
            NPEWAL(IW)    = NPEWAL(IW) + 1
            NPEPMT(IADDR) = NPEPMT(IADDR) + 1
            GO TO 500
*
*-- If it hits xenon surface
*
         ELSE IF ((IHIT .EQ. 2) .AND. (FILL .LT. 1.0)) THEN
            X(1) = XHIT(1)
            X(2) = XHIT(2)
            X(3) = XHIT(3)
            IF (RFLG .EQ. 1) THEN ! xenon->vacuum or xenon->xenon
               CTH1 = V(2)
               IF (ACOS(CTH1) .GT. CRAGXV) THEN ! total reflection
                  V(2) = -V(2)
                  GO TO 300
               ELSE
                  STH1 = SQRT(1-CTH1*CTH1)
                  STH2 = STH1*RFRIDX ! Snell's law
                  CTH2 = SQRT(1-STH2*STH2)
                  RFLCTC = (SIN(ACOS(CTH1)-ACOS(CTH2))**2
     +                 / SIN(ACOS(CTH1)+ACOS(CTH2))**2
     +                 + TAN(ACOS(CTH1)-ACOS(CTH2))**2
     +                 / TAN(ACOS(CTH1)+ACOS(CTH2))**2)*0.5
                  CALL XSRNDM(RN, 1)
                  IF (RN(1) .LT. RFLCTC) THEN
                     V(2) = -V(2) ! normal reflection
                     GO TO 300 
                  ELSE
                     KK   = -CTH1+STH1*STH2/CTH2
                     V(1) = V(1)/SQRT(1+KK*KK+2*KK*V(2))
                     V(2) = (V(2)+KK)/SQRT(1+KK*KK+2*KK*V(2))
                     V(3) = V(3)/SQRT(1+KK*KK+2*KK*V(2))
                     RFLG = 0
                     GO TO 300
                  END IF
               END IF
            ELSE                ! vacuum->xenon
               CTH1 = V(2)
               STH1 = SQRT(1-CTH1*CTH1)
               STH2 = STH1/RFRIDX ! Snell's law
               CTH2 = SQRT(1-STH2*STH2)
               KK   = -CTH1+STH1*STH2/CTH2
               V(1) = V(1)/SQRT(1+KK*KK-2*KK*V(2))
               V(2) = (V(2)-KK)/SQRT(1+KK*KK-2*KK*V(2))
               V(3) = V(3)/SQRT(1+KK*KK-2*KK*V(2))
               RFLG = 1
               GO TO 300 
            END IF

*--   If it hits a place outside PMT  -- reflection?
         ELSE IF (IREFL .EQ. 1) THEN
            CALL XSRNDM(RN, 1)
            IF (RN(1) .LT. EREFL) THEN
               IF(IDEREFL .EQ. 0) THEN
                  V(IWALL) = -V(IWALL) ! regular reflection
               ELSE
                  CALL XSRNDM(RN, 2)
                  IF (IWALL .EQ. 1) THEN
                     V(1)= -RN(2)*(3-2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(1)**2)
                     V(2)=COS(DPHAI) *DSINTH
                     V(3)=SIN(DPHAI) *DSINTH
                  ELSE IF(IWALL .EQ. 2) THEN
                     V(2)= -RN(2)*(3-2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(2)**2)
                     V(3)=COS(DPHAI) *DSINTH
                     V(1)=SIN(DPHAI) *DSINTH
                  ELSE IF(IWALL .EQ. 3) THEN
                     V(3)= -RN(2)*(3-2*IFACE)
                     DPHAI = PI * (2 * RN(1))
                     DSINTH = SQRT(1. - V(3)**2)
                     V(1)=COS(DPHAI) *DSINTH
                     V(2)=SIN(DPHAI) *DSINTH
                  END IF
               END IF
               X(1) = XHIT(1)
               X(2) = XHIT(2)
               X(3) = XHIT(3)
               GO TO 300        ! reflected
            ELSE
               GO TO 500
            END IF
         END IF

 500  CONTINUE
*     
 999  CONTINUE
       RETURN
      END
